<?php

function wow_wowanalytics_admin_init()
{
    $wowOptions = get_option('wow_wowanalytics_options');

    // Absolute path to your specific plugin
    $my_plugin = 'wow-analytics/wow-analytics.php';
    if (isset($wowOptions['admin_messages'])) { // check whether to display the message
        add_action('admin_notices' , 'wow_wowanalytics_error');
        return;
    }
    // Check to see if plugin is already active
    if(!is_plugin_active($my_plugin)) {
        return;
    }
    else{
        // Build the url to call, NOTE: uses home_url and thus requires WordPress 3.0
        $url = add_query_arg( array( 'wow-wowanalytics-test-head' => '', 'wow-wowanalytics-test-footer' => '' ), home_url() );


        // Perform the HTTP GET ignoring SSL errors
        $response = wp_remote_get( $url );

        // Grab the response code and make sure the request was sucessful
        $code = (int) wp_remote_retrieve_response_code( $response );

        if ( $code == 200 ) {
            //global $head_footer_errors;
            $head_footer_errors = array();

            // Strip all tabs, line feeds, carriage returns and spaces
            $html = preg_replace( '/[s]/', '', wp_remote_retrieve_body( $response ) );

            // Check to see if we found the existence of wp_head
            if ( ! strstr( $html, '<!--wp_head-->' ) )
                $head_footer_errors['nohead'] = 'Is missing the call to <?php wp_head(); ?> which should appear directly before </head>';
            // Check to see if we found the existence of wp_footer
            /*
            if ( ! strstr( $html, '<!--wp_footer-->' ) )
                $head_footer_errors['nofooter'] = 'Is missing the call to <?php wp_footer(); ?> which should appear directly before </body>';
            */

            // Check to see if we found wp_head and if was located in the proper spot
            /*
            if ( ! strstr( $html, '<!--wp_head--></head>' ) && ! isset( $head_footer_errors['nohead'] ) )
                $head_footer_errors[] = 'Has the call to <?php wp_head(); ?> but it is not called directly before </head>';
            */
            // Check to see if we found wp_footer and if was located in the proper spot
            /*
            if ( ! strstr( $html, '<!--wp_footer--></body>' ) && ! isset( $head_footer_errors['nofooter'] ) )
                $head_footer_errors[] = 'Has the call to <?php wp_footer(); ?> but it is not called directly before </body>';
            */

            // If we found errors with the existence of wp_head or wp_footer hook into admin_notices to complain about it
            if ( ! empty( $head_footer_errors ) )
            {
                add_action ( 'admin_notices', 'wow_wowanalytics_error' );

                $wowOptions['admin_messages'] = $head_footer_errors;
                update_option( 'wow_wowanalytics_options', $wowOptions ) ;

                deactivate_plugins( $my_plugin ); // Deactivate our plugin
                //return new WP_Error( '', 'my favorite toy is dolly');
                return;
            }
        }

        add_settings_section(
            'wow_wowanalytics_main',
            'WOW Analytics Settings',
            'wow_wowanalytics_section_setup',
            'wow_wowanalytics'
        );

        add_settings_field(
            'wow_wowanalytics_clientid_text',
            'Client id',
            'wow_wowanalytics_setting_clientid',
            'wow_wowanalytics',
            'wow_wowanalytics_main'
        );

        add_settings_field(
            'wow_wowanalytics_trackuser_bool',
            'Track individual users?',
            'wow_wowanalytics_setting_trackuser',
            'wow_wowanalytics',
            'wow_wowanalytics_main'
        );

        add_settings_field(
            'wow_wowanalytics_trackdownloads_bool',
            'Track downloads?',
            'wow_wowanalytics_setting_trackdownloads',
            'wow_wowanalytics',
            'wow_wowanalytics_main'
        );

        register_setting(
            'wow_wowanalytics_options',
            'wow_wowanalytics_options',
            'wow_wowanalytics_validate_options'
        );
    }
}

// Explinations about this section
function wow_wowanalytics_section_setup() {
    echo '<p>Please enter your settings below.</p>';
}

// Display and fill the form field
function wow_wowanalytics_setting_clientid() {
    // get option 'text_clientid' value from the database
    $options = get_option('wow_wowanalytics_options');
    $clientid_string = $options['clientid_text'];
    // echo the field
    printf('<input id="clientid_string" type="text" name="wow_wowanalytics_options[clientid_text]" size="50" value="%s" />',
    isset($clientid_string) ? esc_attr($clientid_string) : ''
    );
    ?>
    <button class="button-secondary" id="wow_clientlookup" >Lookup</button>
    <img id="wow_loading" src="<?php echo admin_url('/images/wpspin_light.gif'); ?>" class="waiting" style="display:none;" />
<?php
}

function wow_wowanalytics_setting_trackuser() {
    // get option 'text_clientid' value from the database
    $options = get_option('wow_wowanalytics_options');
    $trackuser_bool = $options['trackuser_bool'];

    printf('<input id="trackuser_bool" type="checkbox" name="wow_wowanalytics_options[trackuser_bool]" %s />',
        isset($trackuser_bool) ? checked( 1, $trackuser_bool, false ) : ''
    );
}

function wow_wowanalytics_setting_trackdownloads() {
    // get option 'text_clientid' value from the database
    $options = get_option('wow_wowanalytics_options');
    $track_downloads_bool = $options['track_downloads_bool'];

    printf('<input id="track_downloads_bool" type="checkbox" name="wow_wowanalytics_options[track_downloads_bool]" %s />',
        isset($track_downloads_bool) ? checked( 1, $track_downloads_bool, false ) : ''
    );
}

function wow_wowanalytics_validate_options($input){
    $valid = array();

    $valid['trackuser_bool'] = array_key_exists('trackuser_bool', $input);
    $valid['track_downloads_bool'] = array_key_exists('track_downloads_bool', $input);
    $valid['clientid_text'] = $input['clientid_text'];

    return $valid;
}
